@@ -54,9 +54,22 @@
 #define PATH_PASSWD     "/etc/passwd"
 #define PATH_WTMP       "/var/adm/wtmpx"
 #define PATH_UTMP       "/var/adm/utmpx"
-#define PATH_SYSLOG     "/var/log/syslog"
+#define PATH_SYSLOG     "/var/adm/message"
 #endif
 
+#ifdef SOLARIS26
+#define HAVE_SNPRINTF
+#define HAVE_VSNPRINTF
+#define HAVE_GETRUSAGE
+#define PID_T_IS_LONG_INT
+#define SOCKLEN_T       int
+#define PATH_TMP        "/tmp"
+#define PATH_VAR_TMP    "/var/tmp"
+#define PATH_PASSWD     "/etc/passwd"
+#define PATH_WTMP       "/var/adm/wtmpx"
+#define PATH_UTMP       "/var/adm/utmpx"
+#define PATH_SYSLOG     "/var/adm/message"
+#endif
 
 #ifdef SOLARIS_OLD
 #define HAVE_GETRUSAGE
@@ -67,10 +80,9 @@
 #define PATH_PASSWD     "/etc/passwd"
 #define PATH_WTMP       "/var/adm/wtmp"
 #define PATH_UTMP       "/var/adm/utmp"
-#define PATH_SYSLOG     "/var/log/syslog"
+#define PATH_SYSLOG     "/var/adm/message"
 #endif
 
-
 #ifdef NEXTSTEP3
 #define HAVE_GETRUSAGE
 #define SIZEOF_IS_LONG_INT
@@ -177,6 +189,61 @@
 #endif
 #endif
 
+#ifdef SUNOS4
+#define HAVE_GETRUSAGE
+#define SOCKLEN_T	int
+#define SA_RESTART	0
+#define O_RSYNC		0
+#define PATH_TMP        "/tmp"
+#define PATH_VAR_TMP    "/var/tmp"
+#define PATH_PASSWD     "/etc/passwd"
+#define PATH_WTMP       "/var/adm/wtmp"
+#define PATH_UTMP       "/etc/utmp"
+#define PATH_SYSLOG     "/var/adm/syslog"
+
+typedef int ssize_t;
+
+#ifndef EXIT_SUCCESS
+#define	EXIT_SUCCESS	0
+#endif
+
+#define difftime(time1,time0) ((double)(time1) - (double)(time0))
+#define memmove(dst,src,len) bcopy((char *)(src), (char *)(dst), (int)(len))
+
+extern char *sys_errlist[];
+
+#define strerror(n) (sys_errlist[(n)])
+
+/* explicit declaration of functions */
+
+#include <memory.h>
+
+extern int accept(int, struct sockaddr *, int *);
+extern int bind(int, struct sockaddr *, int);
+extern void bcopy(char *, char *, int);
+extern void bzero(char *, int);
+extern int connect(int, struct sockaddr *, int);
+extern int fchmod(int, int);
+extern int fclose(/* FILE * */);
+extern int fprintf(/* FILE *, const char *, ... */);
+extern int getrlimit(/* int, struct rlimit * */);
+extern int getrusage(/* int, struct rusage * */);
+extern int ftruncate(int, off_t);
+extern int gettimeofday(struct timeval *, struct timezone *);
+extern int listen(int, int);
+extern void perror(char *);
+extern int remove(const char *);
+extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
+extern int setsockopt(/* int, int, int, char *, int */);
+extern int shutdown(int, int);
+extern int socket(int, int, int);
+extern int sscanf(const char *, const char *, ...);
+extern long time(long *);
+extern int on_exit(void (*)(), caddr_t arg);
+extern openlog(const char *, int, int);
+extern syslog(int, const char *, ...);
+extern closelog(void);
+#endif
 
 #ifndef RANDSAVENAME
 #define RANDSAVENAME	"/etc/prngd-seed"
