@@ -230,6 +230,8 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
       last_seed_stat = time(0);
     }
 
+    seed_internal(NULL);
+
     if (num < 0)
       continue;		/* Ignore rfds and friends, since invalid */
 
@@ -633,6 +635,13 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
           (void)fprintf(stderr, "Opening service fd %d\n",
 	  	egd_query[max_query-1].fd);
 	}
+	/*
+	 * Finally, mix information about the connection into the pool.
+	 * Maybe its coming from TCP and has some foreign port number
+	 * in it. Only count it as '0', because maybe there is no
+	 * entropy in it at all.
+	 */
+	rand_add(&addr, addrlen, 0.0);
       }
     }
 
